@@ -2,7 +2,7 @@
 * application.cpp: Application class
 *-------------------------------------------------------------------------------
 * (c)1999-2001 VideoLAN
-* $Id: application.cpp,v 1.7 2002/03/29 23:27:44 asmax Exp $
+* $Id: application.cpp,v 1.8 2002/04/27 01:15:57 asmax Exp $
 *
 * Authors: Benoit Steiner <benny@via.ecp.fr>
 *
@@ -308,7 +308,11 @@ int C_Application::RetrieveConfig(int iArgc, char* paArg[])
   C_File cFile(strCfgFile);
   if(!cFile.Exists())
   {
+ #ifdef _WIN32
+    strCfgFile = strName;
+ #else
     strCfgFile = CONFIG_PATH "/" + strName;
+ #endif
     C_File cFile(strCfgFile);
     if(!cFile.Exists())
     {
