@@ -2,7 +2,7 @@
 * settings.cpp: Application settings management
 *-------------------------------------------------------------------------------
 * (c)1999-2001 VideoLAN
-* $Id: settings.cpp,v 1.5 2002/03/24 15:56:08 asmax Exp $
+* $Id: settings.cpp,v 1.6 2002/04/10 10:47:18 asmax Exp $
 *
 * Authors: Benoit Steiner <benny@via.ecp.fr>
 *
@@ -31,7 +31,9 @@
 #include "defs.h"
 
 #include <stdio.h>
+#ifdef HAVE_OPENDIR
 #include <dirent.h>
+#endif
 #include <sys/types.h>
 
 #include "common.h"
